/*
 * Copyright (C) 1996-2001 LAAS/CNRS 
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *    - Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *    - Redistributions in binary form must reproduce the above
 *      copyright notice, this list of conditions and the following
 *      disclaimer in the documentation and/or other materials provided
 *      with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT HOLDERS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 */
#include "config.h"
__RCSID("$LAAS: vecteurs.c,v 1.3 2003/02/09 16:31:28 matthieu Exp $");

#include <math.h>
#include <vecteurs.h>
/***
 *** Routines de manipulation de vecteurs
 *** source: nic
 ***/

void
vecfill(float x1, float x2, float x3, float *v)
{
  v[0] = x1;
  v[1] = x2;
  v[2] = x3;
}

void
veccopy(float *v1, float *v2)
{
  v2[0] = v1[0];
  v2[1] = v1[1];
  v2[2] = v1[2];
}

void
crossprod(float *v1, float *v2, float *v)
{
  v[0] = v1[1]*v2[2] - v1[2]*v2[1];
  v[1] = v1[2]*v2[0] - v1[0]*v2[2];
  v[2] = v1[0]*v2[1] - v1[1]*v2[0];
}

void
unitize(float *v1, float *v2)
{
  float norm = sqrt(v1[0]*v1[0] + v1[1]*v1[1] + v1[2]*v1[2]);
  if ( norm < 0.00001 ) 
      return; /* normation failed */
  v2[0] = v1[0]/norm;
  v2[1] = v1[1]/norm;
  v2[2] = v1[2]/norm;
}

void
vecadd(float  *v1, float *v2, float *v)
{
  v[0] = v1[0]+v2[0];
  v[1] = v1[1]+v2[1];
  v[2] = v1[2]+v2[2];
}

void
vecmult(float scal, float *v1, float *v2)
{
  v2[0] = scal*v1[0];
  v2[1] = scal*v1[1];
  v2[2] = scal*v1[2];
}

